# DeepAffex APIv2 Python Client Library

`dfx-apiv2-client` is a Python 3 asyncio client library for the NuraLogix
DeepAffex API.

## Installation

```shell
pip install --upgrade dfx-apiv2-client
```

## Usage

For usage examples, please see https://github.com/nuralogix/dfx-demo-py
or the apiexample.py file in this repo.

For more information, please visit https://deepaffex.ai/developers-api
